import React, { useMemo, useRef} from 'react'
import { Link } from 'react-router-dom'
import {useGoogleAuth} from 'hooks'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faUser } from '@fortawesome/free-solid-svg-icons'
import { AccountPage } from 'pages'
import { Box, Heading, Flex, Spacer, Button, Image, Avatar, HStack, Input } from "@chakra-ui/react"
import Logo from '../img/logo.png'
import {
    Drawer,
    DrawerBody,
    DrawerHeader,
    DrawerOverlay,
    DrawerContent,
    DrawerCloseButton,
    useDisclosure
  } from "@chakra-ui/react"


const Nav = () => {
    const { isSignedIn, signOut, signIn, manager } = useGoogleAuth();
    const handleAuth = () => { isSignedIn ? signOut() : signIn();}
    const authLinkText = useMemo(() => isSignedIn ? "Logout" : "Login", [isSignedIn]);
    const { isOpen, onOpen, onClose } = useDisclosure();
    const btnRef = useRef<HTMLButtonElement>(null);
    const userIcon = isSignedIn ? 
    <Avatar name={manager.firstName + " " + manager.lastName} boxSize="40px" borderRadius="full"  src={manager.imageUrl} alt="profile"/> : null


    return (
        <Flex className="header">
            <Box className="left-nav">
                <Link to="/"><Image src={Logo} alt="project logo"height="110%" width="55%" /></Link>
            </Box>
            <Spacer />
            <HStack className="right-nav" spacing="1px">
                <Box><button>
                    <Link to="/orders">Orders</Link></button></Box>
                <Box><span>|</span></Box>
                <Box><button onClick={handleAuth}>{authLinkText}</button></Box>
                <Box><button ref={btnRef} onClick={onOpen}>{userIcon}</button></Box>
                <Drawer
                    isOpen={isOpen}
                    placement="right"
                    onClose={onClose}
                    finalFocusRef={btnRef}
                    >
                    <DrawerOverlay />
                    <DrawerContent>
                        <DrawerCloseButton size="sm"/>
                        <DrawerHeader align="center" >User Account</DrawerHeader>
                        <DrawerBody>
                            <AccountPage />
                        </DrawerBody>
                    </DrawerContent>
                </Drawer>
            </HStack>
        </Flex>
    )
}

export default Nav
